#!/usr/bin/env python

import os
import sys
import charmhelpers.contrib.ansible
import charmhelpers.payload.execd

# Create the hooks helper which automatically registers the
# required hooks based on the available tags in your playbook.
# By default, running a hook (such as 'config-changed') will
# result in running all tasks tagged with that hook name.

# force unbuffered python stdout, here until charmhelpers.contrib.ansible is
# fixed
os.environ["PYTHONUNBUFFERED"] = "1"

hooks = charmhelpers.contrib.ansible.AnsibleHooks(
    playbook_path='playbook.yaml',
    default_hooks=[
        'config-changed',
        'upgrade-charm',
        'memcached-relation-changed',
        'wsgi-file-relation-changed',
        'website-relation-changed',
        'nrpe-external-master-relation-changed',
        'conn-check-relation-changed',
        'leader-elected',
        'leader-settings-changed',
    ])


@hooks.hook('install', 'upgrade-charm')
def install():
    """Install ansible.

    The hook() helper decorating this install function ensures that after this
    function finishes, any tasks in the playbook tagged with install are
    executed.
    """
    charmhelpers.payload.execd.execd_preinstall()
    charmhelpers.contrib.ansible.install_ansible_support(from_ppa=False)


@hooks.action()
def migrate(build_label, db_user, db_password):
    """usage: migrate build_label=REV db_user=USER db_password=PASSWORD

    Use build_label=current to run the currently deployed asset's migrations
    """
    return {
        'build_label': build_label,
        'migrate_user': db_user,
        'migrate_password': db_password,
    }


@hooks.action()
def preload(build_label, force="false"):
    """usage: preload build_label=BUILD [force=true]"""
    return {
        'build_label': build_label,
        'force_asset_reload': force,
    }


@hooks.action()
def set_devel_path(branch):
    """usage: install_devel_dependencies"""
    return {'branch': branch}


if __name__ == "__main__":
    hooks.execute(sys.argv)
